#
# spec file for package qatlib
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           qatlib
Version:        24.09.0
Release:        1.3
Summary:        Intel QuickAssist Technology Library
License:        BSD-3-Clause
Group:          Hardware/Other
URL:            https://github.com/intel/qatlib
Source:         https://github.com/intel/qatlib/archive/refs/tags/%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  nasm
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(numa)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(zlib)
# This package can be built on all archs, but is useful only on enterprise-class intel.
ExclusiveArch:  x86_64

%package -n libusdm0
Summary:        QuickAssist memory management library

%description -n libusdm0
User space library for memory management.

%package -n libqat4
Summary:        QuickAssist device access library

%description -n libqat4
User space library for accessing Intel QAT devices.

%package devel
Summary:        Development files for qatlib
Group:          Hardware/Other
Requires:       libqat4 = %{version}-%{release}
Requires:       libusdm0 = %{version}-%{release}

%description
This package provides user space libraries that allow access to Intel
QuickAssist devices for hardware-accelerated cryptography.
The QuickAssist APIs allow for finer control over the qat_4xxx devices
than the more general libkcapi.

%description devel
Header files for using the Intel QuickAssist C APIs.
These APIs allow for finer control over the qat_4xxx devices
than the more general libkcapi.

%prep
%autosetup
autoreconf -iv

%build
%configure --disable-static --enable-legacy-algorithms
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
rm -f %{buildroot}%{_libdir}/*.so.[0-9]

%ldconfig_scriptlets -n libusdm0
%ldconfig_scriptlets -n libqat4

%files
%license LICENSE
%doc README.md
%{_mandir}/man8/qat*
%{_unitdir}/qat*
%{_sbindir}/qat*

%files -n libusdm0
%{_libdir}/libusdm.so.0*

%files -n libqat4
%{_libdir}/libqat.so.4*

%files devel
%{_includedir}/qat
%{_libdir}/lib*.so
%{_libdir}/pkgconfig/libqat.pc
%{_libdir}/pkgconfig/libusdm.pc
%{_libdir}/pkgconfig/qatlib.pc

%changelog
* Fri Dec  6 2024 Torsten Duwe <duwe@suse.com>
- update to 24.09.0:
  * Improved performance scaling in multi-thread applications
  * Set core affinity mapping based on NUMA
    (libnuma now required for building)
  * bug fixes, see https://github.com/intel/qatlib#resolved-issues
* Wed Apr  3 2024 pgajdos@suse.com
- version update to 24.02.0
  * Support DC NS (NoSession) APIs
  * Support Symmetric Crypto SM3 & SM4
  * Support Asymmetric Crypto SM2
  * Support DC CompressBound APIs
  * Bug Fixes. See Resolved section in README.md
* Wed Jan  3 2024 Torsten Duwe <duwe@suse.com>
- update to 23.11.0:
  * use new --enable-legacy-algorithms to avoid regressions
  * add support for data compression chaining (hash then compress)
  * add support for additional configuration profiles
  * add support DC NS (NoSession) APIs
  * add support DC CompressBound APIs
  * add Support for Chinese SM{2,3,4} ciphers
  * bump shared library major to 4
  * refactoring, bug fixes and documentation updates
* Tue May 30 2023 Jan Engelhardt <jengelh@inai.de>
- Implement shared library packaging guidelines
- Drop R/TM signs as per
  https://en.opensuse.org/openSUSE:Package_description_guidelines
* Sat Dec  3 2022 Dirk Müller <dmueller@suse.com>
- update to 22.07.2:
  * Changed from yasm to nasm for assembly compilation
  * Added configuration option to use C implementation of soft CRC
    implementation instead of asm
  * Added support for pkg-config
  * Added missing lock around accesses to some global data in qatmgr
  * Fix for QATE-86605 – improve error checking on size param used by qatmgr
    debug function.
  * Fix for issue #10
  * Fixed link to Programmer's Guide
  * Added support for Compression LZ4 and LZ4s algorithms
  * Added support for Compression end-to-end integrity checks
  * Added support for PKE Generic Point Multiply APIs
  * Added support for CPM2.0b
  * Updated library to support new version of QAT APIs
  * Updated qat service to allow compression only and crypto only
    configurations
  * Created qatlib-tests rpm package
  * Added option to configure script to skip building sample code
* Wed Apr 27 2022 Marcus Meissner <meissner@suse.com>
- use source url, switch to .tar.gz as this is used in github upstream
* Wed Oct  6 2021 Torsten Duwe <duwe@suse.com>
- Update to 21.05.0
  * Add support for Compression Deflate algorithm
  * Add communication path to PF driver (PFVFcomms)
  * Enable services based on VF capabilities.
  * Stop service correctly during uninstallation
  * Fix qatmgr foreground option -f
  * Add qatmgr -v option to display version
  * Add version check between qatlib and qatmgr
  * Suppress deprecated warnings from OpenSSL3
  * Fix build with clang
* Wed Oct  6 2021 Torsten Duwe <duwe@suse.com>
- Update to 21.08.0
  * Add support for Compression Deflate algorithm
  * Add communication path to PF driver (PFVFcomms)
  * Enable services based on VF capabilities.
  * Stop service correctly during uninstallation
  * Fix qatmgr foreground option -f
  * Add qatmgr -v option to display version
  * Add version check between qatlib and qatmgr
  * Suppress deprecated warnings from OpenSSL3
  * Fix build with clang
* Sat Jul  3 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 21.05.0:
  * Added support for AES-CCM 192/265
  * Added support for SHA3-224/384/512 (no partials support)
  * Added support for ChaCha20-Poly1305
  * Added support for PKE 8K (RSA, DH, ModExp, ModInv)
  * Fixed device enumeration on different nodes
  * Fixed pci_vfio_set_command for 32 bit builds
* Mon Feb  8 2021 Torsten Duwe <duwe@suse.com>
- re-add _service file, but "disabled".
* Mon Feb  1 2021 Torsten Duwe <duwe@suse.com>
- Freeze service run for Factory
